Crate path

Crate path 

Relative path types for deltadb.

Provides RelPath and [RelPathBuf] — path types that are guaranteed to be relative, normalized, and valid unicode. Internally stored in POSIX (/-delimited) format regardless of host platform.

Adapted from Zed’s util::rel_path module.

Modules

abs_path
rel_path

Enums

PathStyle

Traits

PathExt

Functions

normalize_path
Normalizes a path by resolving . and .. components without requiring the path to exist on disk (unlike canonicalize).